@@ -41,11 +41,11 @@ class kpTransparentColorCell : public QFrame
 Q_OBJECT
 
 public:
-    kpTransparentColorCell (QWidget *parent);
+    explicit kpTransparentColorCell (QWidget *parent);
 
     QSize sizeHint () const override;
 
-signals:
+Q_SIGNALS:
     void transparentColorSelected (int mouseButton);
 
     // lazy
